NuRadioReco package
===================

.. toctree::

    NuRadioReco.detector
    NuRadioReco.eventbrowser
    NuRadioReco.framework
    NuRadioReco.modules
    NuRadioReco.utilities

Module contents
---------------

.. automodule:: NuRadioReco
    :members:
    :undoc-members:
    :show-inheritance:
